import { 
  CommandInteraction, 
  SlashCommandBuilder, 
  PermissionFlagsBits,
  EmbedBuilder,
  ButtonBuilder,
  ButtonStyle,
  ActionRowBuilder,
  Guild,
  CommandInteractionOptionResolver,
  CacheType
} from 'discord.js';
import { guildSettings } from '../utils/guild-settings';
import { getAvailableThemeIds, getTheme, getRandomNickname } from '../utils/themes';

// Create the command builder
export const data = new SlashCommandBuilder()
  .setName('theme')
  .setDescription('Change or view the bot\'s theme')
  .addSubcommand(subcommand => 
    subcommand
      .setName('set')
      .setDescription('Set the bot\'s theme')
      .addStringOption(option => 
        option
          .setName('theme')
          .setDescription('The theme to set')
          .setRequired(true)
          .addChoices(
            ...getAvailableThemeIds().map(id => ({
              name: getTheme(id).name,
              value: id
            }))
          )
      )
  )
  .addSubcommand(subcommand =>
    subcommand
      .setName('info')
      .setDescription('Get information about the current theme')
  )
  .setDefaultMemberPermissions(PermissionFlagsBits.ManageGuild);

// Command execution
export async function execute(interaction: CommandInteraction): Promise<void> {
  if (!interaction.guildId) {
    await interaction.reply({ content: 'This command can only be used in a server.', ephemeral: true });
    return;
  }

  const subcommand = (interaction.options as CommandInteractionOptionResolver<CacheType>).getSubcommand();

  if (subcommand === 'set') {
    const themeId = interaction.options.get('theme')?.value as string;
    
    if (guildSettings.setTheme(interaction.guildId, themeId)) {
      const theme = getTheme(themeId);
      
      // Get a random nickname for this theme
      const nickname = getRandomNickname(themeId);
      
      // Try to update the bot's nickname
      try {
        const guild = interaction.guild as Guild;
        const me = guild.members.cache.get(guild.client.user.id);
        if (me && me.manageable) {
          await me.setNickname(`${nickname} ${theme.emojiIcon}`);
        }
      } catch (error) {
        console.error(`Failed to update nickname in guild ${interaction.guildId}:`, error);
      }
      
      await interaction.reply({
        content: `${theme.emojiIcon} Theme changed to **${theme.name}**! I'll now act like a ${theme.name.toLowerCase()} named **${nickname}**.`,
        ephemeral: false
      });
    } else {
      await interaction.reply({
        content: 'Failed to set theme. Please try again.',
        ephemeral: true
      });
    }
  } else if (subcommand === 'info') {
    const settings = guildSettings.getSettings(interaction.guildId);
    const theme = getTheme(settings.themeId);
    
    const embed = new EmbedBuilder()
      .setTitle(`${theme.emojiIcon} ${theme.name} Theme`)
      .setDescription(`The bot is currently using the **${theme.name}** theme in this server.`)
      .setColor('#3498db')
      .addFields(
        { name: 'Response Chance', value: `${settings.responseChance}%`, inline: true },
        { name: 'Pronoun', value: settings.pronoun, inline: true },
        { name: 'Example Vocalizations', value: theme.vocalizations.slice(0, 3).join('\n'), inline: false },
        { name: 'Example Actions', value: theme.actions.slice(0, 3).map(a => a.replace('PRONOUN', settings.pronoun)).join('\n'), inline: false }
      );
    
    const row = new ActionRowBuilder<ButtonBuilder>()
      .addComponents(
        ...getAvailableThemeIds()
          .filter(id => id !== settings.themeId)
          .slice(0, 5) // Maximum 5 buttons per row
          .map(id => {
            const buttonTheme = getTheme(id);
            return new ButtonBuilder()
              .setCustomId(`theme_${id}`)
              .setLabel(`${buttonTheme.emojiIcon} ${buttonTheme.name}`)
              .setStyle(ButtonStyle.Secondary);
          })
      );
    
    await interaction.reply({
      embeds: [embed],
      components: [row],
      ephemeral: false
    });
  }
}
