import { CatAudioPlayer } from './audio-player';
import { VoiceChannel } from 'discord.js';

/**
 * Manages audio players for multiple guilds
 */
export class AudioPlayerManager {
  private audioPlayers: Map<string, CatAudioPlayer> = new Map();
  
  /**
   * Get an audio player for a specific guild
   * Creates a new one if it doesn't exist
   */
  public getAudioPlayer(guildId: string): CatAudioPlayer {
    if (!this.audioPlayers.has(guildId)) {
      this.audioPlayers.set(guildId, new CatAudioPlayer());
    }
    
    return this.audioPlayers.get(guildId)!;
  }
  
  /**
   * Join a voice channel in a specific guild
   */
  public async joinChannel(
    voiceChannel: VoiceChannel,
    minStayDuration: number,
    maxStayDuration: number,
    minMeowInterval: number,
    maxMeowInterval: number,
    audioFilePrefix: string = ''
  ): Promise<void> {
    const guildId = voiceChannel.guild.id;
    const audioPlayer = this.getAudioPlayer(guildId);
    
    await audioPlayer.joinChannel(
      voiceChannel,
      minStayDuration,
      maxStayDuration,
      minMeowInterval,
      maxMeowInterval,
      audioFilePrefix
    );
  }
  
  /**
   * Check if the bot is in a voice channel in any guild
   */
  public isInAnyVoiceChannel(): boolean {
    // Check all managed audio players
    for (const audioPlayer of this.audioPlayers.values()) {
      if (audioPlayer.isInVoiceChannel()) {
        return true;
      }
    }
    
    return false;
  }
  
  /**
   * Clean up any resources when the bot is shutting down
   */
  public cleanup(): void {
    for (const audioPlayer of this.audioPlayers.values()) {
      audioPlayer.cleanup();
    }
    
    this.audioPlayers.clear();
  }
}
